Lua_ArenaBattleReportWindow = class("Lua_ArenaBattleReportWindow", Lua_Window);
function Lua_ArenaBattleReportWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ArenaBattleReportWindow";
	self.skinName = "ArenaBattleReportWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
	self.showClose = true;
end

function Lua_ArenaBattleReportWindow:buildPanel(go)
	self:superCall("buildPanel", go);
	
	self:addLuaEvent("UPDATE_ARENA_REPORT", self, self.updateShowInfo);
end

function Lua_ArenaBattleReportWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.btnClose:setLocation(300, 400, 0);

	Lua_ProxyManager.getProxy("Lua_ArenaProxy"):sReportInfo();
end

function Lua_ArenaBattleReportWindow:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_ArenaBattleReportWindow:updateShowInfo(msg)
	if msg == nil or #msg.report_list == nil or #msg.report_list <= 0 then
		self:showNone(true);
		if self.itemList then
			self.itemList:setEnable(false);
		end
	else
		self:showNone(false);
		if self.itemList == nil then
			self.itemList = Lua_DragList.new(self.content, 623, 726, Lua_AxisDefine.Vertical);
			self.itemList:setListCell(Lua_ArenaBattleReportItem, 623, 165, 1);
			self.itemList:setLocation(0, -25, 0);
			self.itemList:setCellSpacing(0, 10);
		end
		self.itemList:setEnable(true);
		self.itemList:setArrayData(msg.report_list);
	end
end

function Lua_ArenaBattleReportWindow:showNone(bShow)
	if bShow then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_widget_012", 0, 50, 0, 0);
			self.noneText = UICreate.createLabel(self.content, nil, 0, 18.5, 100, 40, 40);
			self.noneText.pivotValue = 4;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("938680");
			self.noneText:setLangValue(303032);
		end
		self.noneIcon:setEnable(true);
		self.noneText:setEnable(true);
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false);
			self.noneText:setEnable(false);
		end
	end
end




















Lua_ArenaBattleReportItem = class("Lua_ArenaBattleReportItem", Lua_ListCell);
function Lua_ArenaBattleReportItem:ctor(p)
	self:superCall("ctor", p, "ArenaBattleReportItem_skin");
end

function Lua_ArenaBattleReportItem:buildShowItem()
	self:superCall("buildShowItem");

	self.selfAvatar = Lua_AvatarItem.new(self.content);
	self.selfAvatar:setLocation(-220, -10, 0);
	self.selfAvatar:setScale(0.6, 0.6);

	self.fighterAvatar = Lua_AvatarItem.new(self.content);
	self.fighterAvatar:setLocation(-10, -10, 0);
	self.fighterAvatar:setScale(0.6, 0.6);

	self.btnReplay:addClickFuntion(self, self.onBtnReplayClick);
end

function Lua_ArenaBattleReportItem:dispose()
	if self.selfAvatar ~= nil then
		self.selfAvatar:dispose();
		self.selfAvatar = nil;
	end
	if self.fighterAvatar ~= nil then
		self.fighterAvatar:dispose();
		self.fighterAvatar = nil;
	end
	self:superCall("dispose");
end

function Lua_ArenaBattleReportItem:setData(data)
	if data == nil then
		return;
	end
	self.data = data;

	self.txtSelfScore.text = LanUtil.formateStr(":{1}", data.prev_score + data.score);

	self.selfAvatar:setRoleAvatar(data.self_head_id);
	self.txtSelfName.text = data.self_name;

	self.fighterAvatar:setRoleAvatar(data.fighter_head_id);
	self.txtFighterName.text = data.fighter_name;

	-- 1进攻成功，2进攻失败，3防守成功，4防守失败
	if data.fight_state == 1 then
		self.sprItem:setAltas("arena_atlas_2", "ui_djc_window_011");
	elseif data.fight_state == 2 then
		self.sprItem:setAltas("arena_atlas_2", "ui_djc_window_012");
	elseif data.fight_state == 3 then
		self.sprItem:setAltas("arena_atlas_2", "ui_djc_window_011");
	elseif data.fight_state == 4 then
		self.sprItem:setAltas("arena_atlas_2", "ui_djc_window_012");
	end
	self.txtTime.text = Lua_TimeTransform.transSeconds8(data.tick);

	if data.score > 0 then
		self.txtRank.text = LanUtil.formateStr("<color=#009800>+{1}</color>", data.score);
	elseif data.score < 0 then
		self.txtRank.text = LanUtil.formateStr("<color=#ff1a1a>{1}</color>", data.score);
	else
		self.txtRank.text = "<color=#a1a1a1>+0</color>";
	end
end

function Lua_ArenaBattleReportItem:onBtnReplayClick(go)
	if self.data == nil then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.data.fight_record_id);
end