checkRequire("Lua_ArenaOpponentItem");
checkRequire("Lua_AreanBoxItem");
Lua_ArenaMainPanel = class("Lua_ArenaMainPanel", Lua_DisplayObject);
function Lua_ArenaMainPanel:ctor(p)
	self:superCall("ctor", p, "ArenaMainPanel_skin");
end

function Lua_ArenaMainPanel:buildShowItem()
	self:superCall("buildShowItem");
	self.coolTime = 0;

	self:addLuaEvent("UPDATE_ARENA_INFO", self, self.updateShowInfo);
	self:addLuaEvent("UPDATE_ARENA_REWARD", self, self.updateBoxReward);
	self:addLuaEvent("UPDATE_ARENA_OPPONENT", self, self.updateOpponent);
	self:addLuaEvent("PURCHASE_ITEM_SUCCESS", self, self.updateTicket);

	self.refreshBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 769 + self.adaptHeight);
	self.otherRoleBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 627.5 + self.adaptHeight);

	self.titleEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_djc_bg_01", "ui_djc_bg_01", 0, -210)
	self.titleEff.anchorValue = 1

	self.itemList = Lua_DragList.new(self.content, 685, 620 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setListCell(Lua_ArenaOpponentItem, 685, 123, 1);
	self.itemList:setLocation(0, -41.5, 0);
	self.itemList:setCellSpacing(0, 10);
	self.itemList.tweenId = 2002;

	self.redPoint_record = Lua_RedPointIcon.new(self.content, Lua_RedPointList.Arena_Record);
	self.redPoint_record:setRectAnchor(1);
	self.redPoint_record:setLocation(315, -300, 0);

	self.btnHelp:addClickFuntion(self, self.onBtnHelpClick);
	self.btnLineUp:addClickFuntion(self, self.onBtnLineUpClick);
	self.btnReport:addClickFuntion(self, self.onBtnReportClick);
	self.cbSkip.selected = false;
	self.cbSkip:addBoxChange(self, self.onSkipChange);
	self.btnRefresh:addClickFuntion(self, self.onBtnRefreshClick);
	self.sprAddTicket:addClickFuntion(self, self.onAddTicket);

	Lua_ProxyManager.getProxy("Lua_ArenaProxy"):sArenaInfo();
end

function Lua_ArenaMainPanel:dispose()
	DataCenter.preLoadData:removeBySign("Lua_HeroLineupWindow", self, self.onSceneShow);
	self:stopTimer();
	if self.titleEff then
		self.titleEff:dispose();
		self.titleEff = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.redPoint_record ~= nil then
		self.redPoint_record:dispose();
		self.redPoint_record = nil;
	end
	if self.boxArr ~= nil then
		self.boxArr:dispose();
		self.boxArr:clear();
		self.boxArr = nil;
	end
	self:superCall("dispose");
end

function Lua_ArenaMainPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.refreshBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 769 + adaptHeight);
	self.otherRoleBg:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 627.5 + adaptHeight);
	self.itemList:setContentRect(685, 620 + adaptHeight);
end

function Lua_ArenaMainPanel:updateShowInfo()
	local data = DataCenter.arenaData;
	if DataCenter.funcOpenData:isOpened(10313) then
		self.timeText.text = LanUtil.formateStr(303035, os.date(LanUtil.getValue(58), data.start_tick), os.date(LanUtil.getValue(58), data.settle_tick));
		if data.self_cluster_rank <= 0 then
			self.myRank:setLangValue(303000);
		else
			self.myRank.text = LanUtil.formateStr(303001, tostring(data.self_cluster_rank));
		end
	else
		self.timeText.text = LanUtil.formateStr(303034, os.date(LanUtil.getValue(58), data.start_tick), os.date(LanUtil.getValue(58), data.settle_tick));
		if data.self_rank <= 0 then
			self.myRank:setLangValue(303000);
		else
			self.myRank.text = LanUtil.formateStr(303001, tostring(data.self_rank));
		end
	end
	self.myIntegral.text = LanUtil.formateStr(303002, tostring(data.self_score));
	self.cbSkip.selected = data.skip_fight == 1;
	self.txtFree.text = LanUtil.formateStr(303003, tostring(data.free_times));
	self.txtFightTimes.text = LanUtil.formateStr(303004, tostring(data.fight_times));
	-- self.itemList.showTween = true;
	self.itemList:setArrayData(data.role_list);
	self.settleTime = DataCenter.arenaUtil:getConstConfig("settle_time", 1);
	self:updateTicket();
	self:startTimer();
	self:onTimer();
	self:updateBoxReward();
end

function Lua_ArenaMainPanel:updateTicket()
local costList = DataCenter.arenaUtil:getConstConfig("fight_cost", 4);
	self.txtTicketCount.text = DataCenter.packData:getItemCountById(costList[1]);
end

function Lua_ArenaMainPanel:startTimer()
	if self.bTiming ~= true then
		self.bTiming = true;
		self:addTimer("Lua_ArenaMainPanel", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_ArenaMainPanel:stopTimer()
	if self.bTiming == true then
		self.bTiming = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_ArenaMainPanel:onTimer()
	local second = DataCenter.arenaData.settle_tick - DataCenter.roleData.serverTime;
	DataCenter.arenaData.isSettleTime = second <= self.settleTime;
	local day = Mathf.Modf(second / 86400);
	if day >= 1 then
		self.txtCountdown.text = LanUtil.formateStr(303007, Lua_TimeTransform.transSeconds1(second, false, false, false));
	else
		self.txtCountdown.text = LanUtil.formateStr(303007, Lua_TimeTransform.transSeconds1(second));
	end

	if self.coolTime > 1 then
		self.coolTime = self.coolTime - 1;
		self.btnRefresh.label = LanUtil.formateStr(303005, tostring(self.coolTime));
		self.btnRefresh:setBtnEnable(false);
	else
		self.btnRefresh:setLangValue(303006);
		self.btnRefresh:setBtnEnable(true);
	end

	if second <= 0 and self.coolTime <= 0 then
		self:stopTimer();
	end
	-- if second <= 0 then--时间校验
	-- 	Lua_ProxyManager.getProxy("Lua_ArenaProxy"):sArenaInfo();
	-- end
end

function Lua_ArenaMainPanel:updateOpponent()
	self.coolTime = DataCenter.arenaUtil:getConstConfig("refresh_cool_time", 1);
	self.btnRefresh.label = LanUtil.formateStr(303005, tostring(self.coolTime));
	self.btnRefresh:setBtnEnable(false);
	self:startTimer();
	self.itemList.showTween = true;
	self.itemList:setArrayData(DataCenter.arenaData.role_list);
end

function Lua_ArenaMainPanel:updateBoxReward(arr)
	if arr and self.boxArr then
		for i = 1, arr:getSize() do
			for j = 1, self.boxArr:getSize() do
				if self.boxArr[j].data.id == arr[i] then
					self.boxArr[j]:showReceiveEff(true);
					break;
				end
			end
		end
	end

	if self.boxArr == nil then
		self.boxArr = Array();
	end
	local len = self.boxArr:getSize();
	arr = DataCenter.arenaUtil:getBoxArr(1);
	local dataLen = arr:getSize();

	local times = DataCenter.arenaData.fight_times;
	local maxValue = arr[dataLen].id;
	local value = 0;
	local index = 1;
	if times >= maxValue then
		value = maxValue;
	else
		local stepSpace = maxValue / dataLen;
		for i = 1, dataLen do
			if arr[i].id >= times then
				index = i;
				break;
			end
		end
		value = value + stepSpace * (index - 1);
		local num;
		if index <= 1 then
			num = stepSpace / arr[index].id;
			value = value + times * num;
		else
			num = stepSpace / (arr[index].id - arr[index - 1].id);
			value = value + (times - arr[index - 1].id) * num;
		end
	end

	self.barTimes:setMaxValue(maxValue);
	self.barTimes:setValue(value);
	self.barTimes:setText("");

	local maxLen = dataLen > len and dataLen or len;
	local item;
	for i = 1, maxLen do
		item = self.boxArr[i];
		if i > dataLen then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_AreanBoxItem.new(self.content);
				self.boxArr:add(item);
			else
				item:setEnable(true);
			end
			item:setRectAnchor(4);
			item:setLocation(i / dataLen * 650 - 325, 158, 0);
			item:setRectAnchor(7);
			item:setData(arr[i]);
		end
	end
end

function Lua_ArenaMainPanel:onBtnLineUpClick(go)
	local sceneId = DataCenter.heroLineupData:getLineUpSceneId(Lua_HeroUtil.LINEUP_ARENA_ATTACK);
	DataCenter.preLoadData:preShowScene("Lua_HeroLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, nil, sceneId, 0);
end

function Lua_ArenaMainPanel:onSceneShow(param, mp, success)
	if not success then return; end
	param = { Lua_HeroUtil.LINEUP_ARENA_ATTACK, Lua_HeroUtil.LINEUP_ARENA_DEFENSIZE };
	Lua_WindowUtil.openWin("Lua_HeroLineupWindow", Lua_WinParam.ACTION_OPEN, param);
end

function Lua_ArenaMainPanel:onBtnHelpClick(go)
	local tipsData = { des = LanUtil.getValue(303008), posX = 175, posY = -230 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_ArenaMainPanel:onBtnReportClick(go)
	Lua_WindowUtil.openWin("Lua_ArenaBattleReportWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_ArenaMainPanel:onSkipChange(bChange)
	local limitTimes = DataCenter.arenaUtil:getConstConfig("skip_fight_times", 1);
	if DataCenter.arenaData.fight_times < limitTimes then
		OperateAlert.show(LanUtil.formateStr(303009, tostring(limitTimes)));
		self.cbSkip.selected = false;
		return;
	end

	self.cbSkip.selected = bChange;
	Lua_ProxyManager.getProxy("Lua_ArenaProxy"):sSkipFight();
end

function Lua_ArenaMainPanel:onAddTicket(go)
	if DataCenter.arenaData.recharge_times <= 0 then
		OperateAlert.showLangValue(303026);
		return;
	end
	Lua_WindowUtil.openWin("Lua_ArenaChallengeTicketBuyWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_ArenaMainPanel:onBtnRefreshClick(go)
	Lua_ProxyManager.getProxy("Lua_ArenaProxy"):sRefreshOpponent();
end