Lua_ArenaOpponentItem = class("Lua_ArenaOpponentItem", Lua_ListCell);
function Lua_ArenaOpponentItem:ctor(p)
	self:superCall("ctor", p, "ArenaOpponentItem_skin");
end

function Lua_ArenaOpponentItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setLocation(-275, 0, 0);
	self.avatarItem:setScale(0.8, 0.8);

	self.btnChallenge:addClickFuntion(self, self.onBtnChallengeClick);
end

function Lua_ArenaOpponentItem:dispose()
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

-- 变量名：player_id	说明：玩家id
-- 变量名：name	说明：玩家名字
-- 变量名：head_id	说明：头像id
-- 变量名：level	说明：等级
-- 变量名：score	说明：积分
-- 变量名：force	说明：战力
-- 变量名：rank	说明：排名值
-- 变量名：is_league	说明：是否盟友：1是，0否
-- 变量名：league_name	说明：帮派名字
-- 变量名：like_num	说明：点赞数
-- 变量名：like_state	说明：是否点赞过该玩家：1是，0否
-- 变量名：fashion_id	说明：时装id
function Lua_ArenaOpponentItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end
	
	self.avatarItem:setRoleId(data.player_id, data.server_flag, data.is_robot)
	self.avatarItem:setRoleAvatar(data.head_id);
	self.avatarItem:setRoleLevel(data.level);

	if not DataCenter.funcOpenData:isOpened(10313) or data.is_robot ~= 0 then
		self.txtName.text = data.name;
	else
		self.txtName.text = LanUtil.formateStr(10051, data.server_prev, data.name);
	end

	local force = DataCenter.roleData.force;
	local value = DataCenter.arenaUtil:getConstConfig("fight_force_percent", 2);
	if data.force > force * value then
		self.powerTxt.text = Lua_ColorDefine.getColorStr("E01B1B", LanUtil.formateStr(303010, data.force));
	else
		self.powerTxt.text = Lua_ColorDefine.getColorStr("927567", LanUtil.formateStr(303010, data.force));
	end

	self.txtIntegral.text = data.score;
	self.sprAlly:setEnable(data.is_league == 1);

	if DataCenter.arenaData.free_times > 0 then
		self.btnChallenge:setLangValue(303011);
	else
		self.btnChallenge.label = LanUtil.formateStr(303012, spliceIconStr("item_altas_1", "204020001", 35, 35));
	end
end

function Lua_ArenaOpponentItem:onBtnChallengeClick(go)
	if self.data == nil or DataCenter.arenaData.isSettleTime == true then
		OperateAlert.showLangValue(303025);
		return;
	end

	if DataCenter.arenaData.free_times > 0 then
		self:onStartFight();
	else
		local costList = DataCenter.arenaUtil:getConstConfig("fight_cost", 4);
		local costId = DataCenter.packData:checkConsumeEnough(costList);
		if costId == nil then
			self:onStartFight();
		else
			DataCenter.packUtil:openPathWindow(costId, false);
		end
	end
end

function Lua_ArenaOpponentItem:onStartFight()
	local force = DataCenter.roleData.force;
	local value = DataCenter.arenaUtil:getConstConfig("fight_force_percent", 2);
	if not DataCenter.neverTipData:getNeverValue(Lua_NeverTipDefine.ARENA_REMIND) and self.data.force > force * value then
		local tipsData = { des = LanUtil.formateStr(303021, tostring(self.data.force)), width = 565, posY = 50,
		 btnType = 1, neverTip = Lua_NeverTipDefine.ARENA_REMIND, owner = self, sureFun = self.onSureFun };
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	else
		self:onSureFun();
	end
end

function Lua_ArenaOpponentItem:onSureFun()
	Lua_ProxyManager.getProxy("Lua_FightProxy"):sStartFight(Lua_FightDefine.TEMPLATE_ID_ARENA, 0, self.data.player_id);
end